@@ -21,12 +21,10 @@ window.unifiConfig = {
 };
 
 window.unifiConstant = {
-  DISCOVERY_TOOL_KEY: 'hmpigflbjeapnknladcfphgkemopofig',
-  DISCOVERY_TOOL_LATEST_VERSION: '0.2.36',
-  GoogleMapsApiKey: '',
+  GoogleMapsApiKey: 'AIzaSyDW1OnFXY2kzpH77F7fEB66WlkFRtKX3p4',
   GoogleAnalyticsCloudKey: 'UA-2432820-22',
   GoogleAnalyticsDemoKey: 'UA-2432820-34',
-  VERSION: '5.3.11.0'
+  VERSION: '5.4.9.1'
 };
 
 window.webrtcConfig = {
@@ -41,3 +39,7 @@ window.webrtcConfig = {
   UseWebrtc: false,
   VersionCheckEnabled: true
 };
+
+window.unifiSharedConstant = {
+  DISCOVERY_TOOL_KEY: 'hmpigflbjeapnknladcfphgkemopofig'
+};
